@@ -11,7 +11,12 @@ import publication
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-servicecatalog", "1.49.1", __name__[0:-6], "aws-servicecatalog@1.49.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-servicecatalog",
+    "1.52.0",
+    __name__[0:-6],
+    "aws-servicecatalog@1.52.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
